@@ -48,7 +48,7 @@ __author__: str = "Dominic Davis-Foster"
 __copyright__: str = "2020 Dominic Davis-Foster"
 
 __license__: str = "MIT"
-__version__: str = "0.0.10"
+__version__: str = "0.0.11"
 __email__: str = "dominic@davis-foster.co.uk"
 
 __all__ = ["process_docstring", "process_default_format", "setup"]
@@ -100,7 +100,7 @@ def process_docstring(app: Sphinx, what, name, obj, options, lines: typing.List[
 			formatted_annotation = None
 
 			# Get the default value from the signature
-			if default_value not in {inspect.Signature.empty, Ellipsis}:  # type: ignore
+			if default_value is not inspect.Signature.empty and default_value is not Ellipsis:
 
 				if isinstance(default_value, bool):
 					formatted_annotation = f":py:obj:`{default_value}`"
